@@ -3,6 +3,7 @@ import logging
 
 import jaraco
 
+from ._itertools import single
 from .helpers import urls
 from .helpers import errors as ERROR
 
@@ -13,7 +14,6 @@ class Automation:
     """Class for viewing and controlling automations."""
 
     def __init__(self, abode, automation):
-        """Init Automation class."""
         self._client = abode
         self._automation = automation
 
@@ -27,10 +27,7 @@ class Automation:
             method="patch", path=path, data={'enabled': enable}
         )
 
-        response_object = response.json()
-
-        if isinstance(response_object, (tuple, list)):
-            response_object = response_object[0]
+        response_object = single(response.json())
 
         if str(response_object['id']) != str(self._automation['id']) or str(
             response_object['enabled']
@@ -55,10 +52,7 @@ class Automation:
         path = urls.AUTOMATION_ID.format(id=self.automation_id)
 
         response = self._client.send_request(method="get", path=path)
-        response_object = response.json()
-
-        if isinstance(response_object, (tuple, list)):
-            response_object = response_object[0]
+        response_object = single(response.json())
 
         if str(response_object['id']) != self.automation_id:
             raise jaraco.abode.Exception(ERROR.INVALID_AUTOMATION_REFRESH_RESPONSE)
