@@ -5,11 +5,13 @@ An Abode alarm Python library.
 import logging
 import uuid
 
-from more_itertools import always_iterable
+from more_itertools import consume
 from requests_toolbelt import sessions
 from requests.exceptions import RequestException
 from jaraco.net.http import cookies
 from jaraco.functools import retry
+from jaraco.itertools import always_iterable
+from jaraco.collections import Everything
 
 import jaraco
 from .automation import Automation
@@ -47,7 +49,6 @@ class Client:
         get_devices=False,
         get_automations=False,
     ):
-        """Init Abode object."""
         self._session = None
         self._token = None
         self._panel = None
@@ -75,7 +76,7 @@ class Client:
         if get_automations:
             self.get_automations()
 
-    def login(self, username=None, password=None, mfa_code=None):  # noqa: C901
+    def login(self, username=None, password=None, mfa_code=None):
         """Explicit Abode login."""
 
         self._token = None
@@ -159,10 +160,14 @@ class Client:
         if refresh or self._devices is None:
             self._load_devices()
 
+        spec_types = (
+            Everything() if generic_type is None else set(always_iterable(generic_type))
+        )
+
         return [
             device
             for device in self._devices.values()
-            if not generic_type or device.generic_type == generic_type
+            if device.generic_type in spec_types
         ]
 
     def _load_devices(self):
@@ -171,29 +176,11 @@ class Client:
 
         _LOGGER.info("Updating all devices...")
         response = self.send_request("get", urls.DEVICES)
-        response_object = response.json()
-
-        if response_object and not isinstance(response_object, (tuple, list)):
-            response_object = [response_object]
+        devices = always_iterable(response.json())
 
         _LOGGER.debug("Get Devices Response: %s", response.text)
 
-        for device_json in response_object:
-            # Attempt to reuse an existing device
-            device = self._devices.get(device_json['id'])
-
-            # No existing device, create a new one
-            if device:
-                device.update(device_json)
-            else:
-                device = Device.new(device_json, self)
-
-                if not device:
-                    _LOGGER.debug("Skipping unknown device: %s", device_json)
-
-                    continue
-
-                self._devices[device.device_id] = device
+        consume(map(self._load_device, devices))
 
         # We will be treating the Abode panel itself as an armable device.
         panel_response = self.send_request("get", urls.PANEL)
@@ -203,7 +190,7 @@ class Client:
 
         _LOGGER.debug("Get Mode Panel Response: %s", response.text)
 
-        alarm_device = self._devices.get(CONST.ALARM_DEVICE_ID + '1')
+        alarm_device = self._devices.get(ALARM.id(1))
 
         if alarm_device:
             alarm_device.update(self._panel)
@@ -211,6 +198,27 @@ class Client:
             alarm_device = ALARM.create_alarm(self._panel, self)
             self._devices[alarm_device.device_id] = alarm_device
 
+    def _load_device(self, doc):
+        self._reuse_device(doc) or self._create_new_device(doc)
+
+    def _reuse_device(self, doc):
+        device = self._devices.get(doc['id'])
+
+        if not device:
+            return
+
+        device.update(doc)
+        return device
+
+    def _create_new_device(self, doc):
+        device = Device.new(doc, self)
+
+        if not device:
+            _LOGGER.debug("Skipping unknown device: %s", doc)
+            return
+
+        self._devices[device.device_id] = device
+
     def get_device(self, device_id, refresh=False):
         """Get a single device."""
         if self._devices is None:
@@ -235,7 +243,7 @@ class Client:
             resp = self.send_request("get", urls.AUTOMATION)
             _LOGGER.debug("Get Automations Response: %s", resp.text)
 
-            for automation_ob in always_iterable(resp.json(), base_type=dict):
+            for automation_ob in always_iterable(resp.json()):
                 # Attempt to reuse an existing automation object
                 automation = self._automations.get(str(automation_ob['id']))
 
@@ -263,7 +271,7 @@ class Client:
 
     def get_alarm(self, area='1', refresh=False):
         """Shortcut method to get the alarm device."""
-        return self.get_device(CONST.ALARM_DEVICE_ID + area, refresh)
+        return self.get_device(ALARM.id(area), refresh)
 
     def set_default_mode(self, default_mode):
         """Set the default mode when alarms are turned 'on'."""
