@@ -2,37 +2,39 @@
 import logging
 import math
 
-from ..exceptions import AbodeException
-
-from ..devices.switch import AbodeSwitch
+import jaraco
 from ..helpers import constants as CONST
 from ..helpers import errors as ERROR
+from ..helpers import urls
 from .control import needs_control_url
+from .switch import Switch
 
 
 _LOGGER = logging.getLogger(__name__)
 
 
-class AbodeLight(AbodeSwitch):
+class Light(Switch):
     """Class for lights (dimmers)."""
 
+    implements = CONST.TYPE_LIGHT
+
     @needs_control_url
     def set_color_temp(self, color_temp):
         """Set device color."""
-        url = CONST.INTEGRATIONS_URL + self._device_uuid
+        url = urls.INTEGRATIONS + self._device_uuid
 
         color_data = {
             'action': 'setcolortemperature',
             'colorTemperature': int(color_temp),
         }
 
-        response = self._abode.send_request("post", url, data=color_data)
+        response = self._client.send_request("post", url, data=color_data)
         response_object = response.json()
 
         _LOGGER.debug("Set Color Temp Response: %s", response.text)
 
         if response_object['idForPanel'] != self.device_id:
-            raise AbodeException(ERROR.SET_STATUS_DEV_ID)
+            raise jaraco.abode.Exception(ERROR.SET_STATUS_DEV_ID)
 
         if response_object['colorTemperature'] != int(color_temp):
             _LOGGER.warning(
@@ -54,7 +56,7 @@ class AbodeLight(AbodeSwitch):
     @needs_control_url
     def set_color(self, color):
         """Set device color."""
-        url = CONST.INTEGRATIONS_URL + self._device_uuid
+        url = urls.INTEGRATIONS + self._device_uuid
 
         hue, saturation = color
         color_data = {
@@ -63,13 +65,13 @@ class AbodeLight(AbodeSwitch):
             'saturation': int(saturation),
         }
 
-        response = self._abode.send_request("post", url, data=color_data)
+        response = self._client.send_request("post", url, data=color_data)
         response_object = response.json()
 
         _LOGGER.debug("Set Color Response: %s", response.text)
 
         if response_object['idForPanel'] != self.device_id:
-            raise AbodeException(ERROR.SET_STATUS_DEV_ID)
+            raise jaraco.abode.Exception(ERROR.SET_STATUS_DEV_ID)
 
         # Abode will sometimes return hue value off by 1 (rounding error)
         hue_comparison = math.isclose(response_object["hue"], int(hue), abs_tol=1)
