@@ -1,12 +1,16 @@
 """Abode switch device."""
 
-from ..devices import AbodeDevice
+from typing import Optional, Union, Iterable
+
 from ..helpers import constants as CONST
+from . import base
 
 
-class AbodeSwitch(AbodeDevice):
+class Switch(base.Device):
     """Class to add switch functionality."""
 
+    implements: Optional[Union[str, Iterable[str]]] = CONST.TYPE_SWITCH
+
     def switch_on(self):
         """Turn the switch on."""
         success = self.set_status(CONST.STATUS_ON_INT)
