@@ -1,6 +1,9 @@
 """Abode cloud push events."""
 import collections
 import logging
+import http.cookiejar
+
+from jaraco.itertools import always_iterable
 
 import jaraco
 from .devices.base import Device
@@ -9,16 +12,27 @@ from .helpers import constants as CONST
 from .helpers import errors as ERROR
 from .helpers import timeline as TIMELINE
 from . import socketio as sio
+from ._itertools import single, opt_single
 
 _LOGGER = logging.getLogger(__name__)
 
 
-class EventController:
-    """Class for subscribing to abode events."""
+def _cookie_string(cookies: http.cookiejar.CookieJar):
+    """
+    >>> jar = http.cookiejar.CookieJar()
+    >>> from test.test_http_cookiejar import interact_netscape
+    >>> _ = interact_netscape(jar, 'http://any/', 'foo=bar', 'bing=baz')
+    >>> _cookie_string(jar) in ['foo=bar; bing=baz', 'bing=baz; foo=bar']
+    True
+    """
+    return "; ".join(f"{cookie.name}={cookie.value}" for cookie in cookies)
 
-    def __init__(self, abode, url=CONST.SOCKETIO_URL):
-        """Init event subscription class."""
-        self._client = abode
+
+class EventController:
+    """Subscribes to events."""
+
+    def __init__(self, client, url=CONST.SOCKETIO_URL):
+        self._client = client
         self._thread = None
         self._running = False
         self._connected = False
@@ -33,13 +47,13 @@ class EventController:
         self._socketio = sio.SocketIO(url=url, origin=urls.BASE)
 
         # Setup SocketIO Callbacks
-        self._socketio.on(sio.STARTED, self._on_socket_started)
-        self._socketio.on(sio.CONNECTED, self._on_socket_connected)
-        self._socketio.on(sio.DISCONNECTED, self._on_socket_disconnected)
-        self._socketio.on(CONST.DEVICE_UPDATE_EVENT, self._on_device_update)
-        self._socketio.on(CONST.GATEWAY_MODE_EVENT, self._on_mode_change)
-        self._socketio.on(CONST.TIMELINE_EVENT, self._on_timeline_update)
-        self._socketio.on(CONST.AUTOMATION_EVENT, self._on_automation_update)
+        self._socketio.on('started', self._on_socket_started)
+        self._socketio.on('connected', self._on_socket_connected)
+        self._socketio.on('disconnected', self._on_socket_disconnected)
+        self._socketio.on('com.goabode.device.update', self._on_device_update)
+        self._socketio.on('com.goabode.gateway.mode', self._on_mode_change)
+        self._socketio.on('com.goabode.gateway.timeline', self._on_timeline_update)
+        self._socketio.on('com.goabode.automation', self._on_automation_update)
 
     def start(self):
         """Start a thread to handle Abode SocketIO notifications."""
@@ -76,10 +90,7 @@ class EventController:
         if not devices:
             return False
 
-        if not isinstance(devices, (tuple, list)):
-            devices = [devices]
-
-        for device in devices:
+        for device in always_iterable(devices):
             # Device may be a device_id
             device_id = device
 
@@ -102,10 +113,7 @@ class EventController:
         if not devices:
             return False
 
-        if not isinstance(devices, (tuple, list)):
-            devices = [devices]
-
-        for device in devices:
+        for device in always_iterable(devices):
             device_id = device
 
             if isinstance(device, Device):
@@ -128,13 +136,10 @@ class EventController:
         if not event_groups:
             return False
 
-        if not isinstance(event_groups, (tuple, list)):
-            event_groups = [event_groups]
-
-        for event_group in event_groups:
-            if event_group not in TIMELINE.ALL_EVENT_GROUPS:
+        for event_group in always_iterable(event_groups):
+            if event_group not in TIMELINE.Groups.ALL:
                 raise jaraco.abode.Exception(
-                    ERROR.EVENT_GROUP_INVALID, TIMELINE.ALL_EVENT_GROUPS
+                    ERROR.EVENT_GROUP_INVALID, TIMELINE.Groups.ALL
                 )
 
             _LOGGER.debug("Subscribing to event group: %s", event_group)
@@ -148,10 +153,7 @@ class EventController:
         if not timeline_events:
             return False
 
-        if not isinstance(timeline_events, (tuple, list)):
-            timeline_events = [timeline_events]
-
-        for timeline_event in timeline_events:
+        for timeline_event in always_iterable(timeline_events):
             if not isinstance(timeline_event, dict):
                 raise jaraco.abode.Exception(ERROR.EVENT_CODE_MISSING)
 
@@ -178,10 +180,7 @@ class EventController:
 
     def _on_socket_started(self):
         """Socket IO startup callback."""
-        cookies = self._client._get_session().cookies.get_dict()
-        cookie_string = "; ".join([str(x) + "=" + str(y) for x, y in cookies.items()])
-
-        self._socketio.set_cookie(cookie_string)
+        self._socketio.set_cookie(_cookie_string(self._client._get_session().cookies))
 
     def _on_socket_connected(self):
         """Socket IO connected callback."""
@@ -195,7 +194,7 @@ class EventController:
             # Callbacks should still execute even if refresh fails (Abode
             # server issues) so that the entity availability in Home Assistant
             # is updated since we are in fact connected to the web socket.
-            for callbacks in self._connection_status_callbacks.values:
+            for callbacks in self._connection_status_callbacks.values():
                 for callback in callbacks:
                     _execute_callback(callback)
 
@@ -209,8 +208,7 @@ class EventController:
 
     def _on_device_update(self, devid):
         """Device callback from Abode SocketIO server."""
-        if isinstance(devid, (tuple, list)):
-            devid = devid[0]
+        devid = opt_single(devid)
 
         if devid is None:
             _LOGGER.warning("Device update with no device id.")
@@ -229,8 +227,7 @@ class EventController:
 
     def _on_mode_change(self, mode):
         """Mode change broadcast from Abode SocketIO server."""
-        if isinstance(mode, (tuple, list)):
-            mode = mode[0]
+        mode = opt_single(mode)
 
         if mode is None:
             _LOGGER.warning("Mode change event with no mode.")
@@ -255,8 +252,7 @@ class EventController:
 
     def _on_timeline_update(self, event):
         """Timeline update broadcast from Abode SocketIO server."""
-        if isinstance(event, (tuple, list)):
-            event = event[0]
+        event = single(event)
 
         event_type = event.get('event_type')
         event_code = event.get('event_code')
@@ -289,10 +285,9 @@ class EventController:
 
     def _on_automation_update(self, event):
         """Automation update broadcast from Abode SocketIO server."""
-        event_group = TIMELINE.AUTOMATION_EDIT_GROUP
+        event_group = TIMELINE.Groups.AUTOMATION_EDIT
 
-        if isinstance(event, (tuple, list)):
-            event = event[0]
+        event = single(event)
 
         for callback in self._event_callbacks[event_group]:
             _execute_callback(callback, event)
