@@ -5,11 +5,6 @@ SOCKETIO_HEADERS = {
     'Origin': 'https://my.goabode.com/',
 }
 
-DEVICE_UPDATE_EVENT = 'com.goabode.device.update'
-GATEWAY_MODE_EVENT = 'com.goabode.gateway.mode'
-TIMELINE_EVENT = 'com.goabode.gateway.timeline'
-AUTOMATION_EVENT = 'com.goabode.automation'
-
 # DICTIONARIES
 MODE_STANDBY = 'standby'
 MODE_HOME = 'home'
@@ -183,9 +178,3 @@ type_map = {
 def get_generic_type(type_tag):
     """Map type tag to generic type."""
     return type_map.get(type_tag.lower())
-
-
-# Constants to be used to fill our imaginary alarm device
-ALARM_NAME = "Abode Alarm"
-ALARM_DEVICE_ID = "area_"
-ALARM_TYPE = "Alarm"
