@@ -1,6 +1,7 @@
 """Test the Abode camera class."""
 import base64
 import os
+import pathlib
 
 import pytest
 
@@ -19,13 +20,10 @@ from .mock import oauth_claims as OAUTH_CLAIMS
 from .mock import panel as PANEL
 
 
-def set_cam_type(device_type):
-    """Return camera type_tag."""
-    if device_type == CONST.DEVICE_IP_CAM:
-        return IPCAM
-
-    if device_type == CONST.DEVICE_MOTION_CAMERA:
-        return IRCAMERA
+cam_types = {
+    CONST.DEVICE_IP_CAM: IPCAM,
+    CONST.DEVICE_MOTION_CAMERA: IRCAMERA,
+}
 
 
 def all_devices():
@@ -65,11 +63,11 @@ class TestCamera:
             if device.type_tag != CONST.DEVICE_ALARM
         )
 
-    def tests_camera_properties(self, m):
+    def test_camera_properties(self, m):
         """Tests that camera properties work as expected."""
         for device in self.camera_devices():
             # Specify which device module to use based on type_tag
-            cam_type = set_cam_type(device.type_tag)
+            cam_type = cam_types[device.type_tag]
 
             # Test our device
             assert device is not None
@@ -98,11 +96,11 @@ class TestCamera:
             assert device.battery_low
             assert device.no_response
 
-    def tests_camera_capture(self, m):
+    def test_camera_capture(self, m):
         """Tests that camera devices capture new images."""
         for device in self.camera_devices():
             # Specify which device module to use based on type_tag
-            cam_type = set_cam_type(device.type_tag)
+            cam_type = cam_types[device.type_tag]
 
             # Test that we have the camera devices
             assert device is not None
@@ -138,11 +136,11 @@ class TestCamera:
                 device.capture()
             assert (exc.value.errcode, exc.value.message) == ERROR.MISSING_CONTROL_URL
 
-    def tests_camera_image_update(self, m):
+    def test_camera_image_update(self, m):
         """Tests that camera devices update correctly via timeline request."""
         for device in self.camera_devices():
             # Specify which device module to use based on type_tag
-            cam_type = set_cam_type(device.type_tag)
+            cam_type = cam_types[device.type_tag]
 
             # Test that we have our device
             assert device is not None
@@ -201,7 +199,7 @@ class TestCamera:
             with pytest.raises(jaraco.abode.Exception):
                 device.refresh_image()
 
-    def tests_camera_no_image_update(self, m):
+    def test_camera_no_image_update(self, m):
         """Tests that camera updates correctly with no timeline events."""
         for device in self.camera_devices():
             # Test that we have our device
@@ -216,11 +214,11 @@ class TestCamera:
             assert not device.refresh_image()
             assert device.image_url is None
 
-    def tests_camera_image_write(self, m):
+    def test_camera_image_write(self, m):
         """Tests that camera images will write to a file."""
         for device in self.camera_devices():
             # Specify which device module to use based on type_tag
-            cam_type = set_cam_type(device.type_tag)
+            cam_type = cam_types[device.type_tag]
 
             # Test that we have our device
             assert device is not None
@@ -246,7 +244,7 @@ class TestCamera:
             assert device.image_to_file(path, get_image=True)
 
             # Test the file written and cleanup
-            image_data = open(path).read()
+            image_data = pathlib.Path(path).read_text()
             assert image_response, image_data
             os.remove(path)
 
@@ -259,11 +257,11 @@ class TestCamera:
             m.get(url, json=[])
             assert not device.image_to_file(path, get_image=True)
 
-    def tests_camera_snapshot(self, m):
+    def test_camera_snapshot(self, m):
         """Tests that camera devices capture new snapshots."""
         for device in self.camera_devices():
             # Specify which device module to use based on type_tag
-            cam_type = set_cam_type(device.type_tag)
+            cam_type = cam_types[device.type_tag]
 
             # Test that we have our device
             assert device is not None
@@ -284,11 +282,11 @@ class TestCamera:
             m.post(snapshot_url, json={})
             assert not device.snapshot()
 
-    def tests_camera_snapshot_write(self, m):
+    def test_camera_snapshot_write(self, m):
         """Tests that camera snapshots will write to a file."""
         for device in self.camera_devices():
             # Specify which device module to use based on type_tag
-            cam_type = set_cam_type(device.type_tag)
+            cam_type = cam_types[device.type_tag]
 
             # Test that we have our device
             assert device is not None
@@ -305,7 +303,7 @@ class TestCamera:
             assert device.snapshot_to_file(path, get_snapshot=True)
 
             # Test the file written and cleanup
-            image_data = open(path, "rb").read()
+            image_data = pathlib.Path(path).read_bytes()
             assert image_response == image_data
             os.remove(path)
 
@@ -313,11 +311,11 @@ class TestCamera:
             m.post(snapshot_url, json=cam_type.get_capture_timeout(), status_code=600)
             assert not device.snapshot_to_file(path, get_snapshot=True)
 
-    def tests_camera_snapshot_data_url(self, m):
+    def test_camera_snapshot_data_url(self, m):
         """Tests that camera snapshots can be converted to a data url."""
         for device in self.camera_devices():
             # Specify which device module to use based on type_tag
-            cam_type = set_cam_type(device.type_tag)
+            cam_type = cam_types[device.type_tag]
 
             # Test that we have our device
             assert device is not None
@@ -342,7 +340,7 @@ class TestCamera:
             m.post(snapshot_url, json=cam_type.get_capture_timeout(), status_code=600)
             assert device.snapshot_data_url(get_snapshot=True) == ""
 
-    def tests_camera_privacy_mode(self, m):
+    def test_camera_privacy_mode(self, m):
         """Tests camera privacy mode."""
 
         # Get the IP camera and test we have it
